@@ -7,6 +7,7 @@ kristine larson
 import argparse
 import gnssrefl.gps as g
 import sys
+import subprocess
 
 
 def main():
@@ -24,7 +25,7 @@ def main():
 #   make sure environment variables exist.  set to current directory if not
     g.check_environ_variables()
 
-    orbit_list = ['igs', 'igr','jax','grg','wum','gbm','nav','gps','gps+glo','gnss']
+    orbit_list = ['igs', 'igr','jax','grg','wum','gbm','nav','gps','gps+glo','gnss','gfr']
 
 
 #   assign to normal variables
@@ -69,7 +70,10 @@ def main():
         if (pCtr == 'igs') or (pCtr == 'igr'):
             filename, fdir, foundit = g.getsp3file_flex(year,month,day,pCtr)
         else:
-            filename, fdir, foundit = g.getsp3file_mgex(year,month,day,pCtr)
+            if pCtr == 'gfr':
+                filename, fdir, foundit = g.rapid_gfz_orbits(year,month,day)
+            else:
+                filename, fdir, foundit = g.getsp3file_mgex(year,month,day,pCtr)
         if foundit:
             print('SUCCESS:', fdir+'/'+filename )
         else:
