@@ -13,6 +13,7 @@ import scipy.signal
 import subprocess
 import sys
 import warnings
+import wget
 
 import gnssrefl.gnssir as guts
 import gnssrefl.gps as g
@@ -178,6 +179,23 @@ def main():
 
     lsp['mmdd'] = add_mmddhhss
 
+    xdir = str(os.environ['REFL_CODE'])
+    picklefile = 'gpt_1wA.pickle'
+    pname = xdir + '/input/' + picklefile
+
+    if os.path.isfile(pname):
+        print('refraction file exists')
+    else:
+        local_copy = 'gnssrefl/' + picklefile
+        if os.path.isfile(local_copy):
+            print('found local copy of refraction file')
+            subprocess.call(['cp','-f',local_copy, xdir + '/input/' ])
+        else:
+            print('download and move refraction file')
+            url='https://github.com/kristinemlarson/gnssrefl/raw/master/gnssrefl/gpt_1wA.pickle'
+            wget.download(url,picklefile)
+            subprocess.call(['mv','-f',picklefile, xdir + '/input/' ])
+
     year_list = list(range(year, year_end+1))
     doy_list = list(range(doy, doy_end+1))
     for year in year_list:
