@@ -33,6 +33,10 @@ def read_snr_simple(obsfile):
     try:
         f = np.genfromtxt(obsfile,comments='%')
         r,c = f.shape
+        # put in a positive elev mask
+        i= f[:,1] > 0
+        f=f[i,:]
+
         #print('read_snr_simple, Number of rows:', r, ' Number of columns:',c)
         sat = f[:,0]; ele = f[:,1]; azi = f[:,2]; t =  f[:,3]
         edot =  f[:,4]; s1 = f[:,6]; s2 = f[:,7]; s6 = f[:,5]
@@ -115,6 +119,8 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     # define where the axes are located
     bx = [0,1,0,1]; by = [0,0,1,1]; bz = [1,3,2,4]
 
+    # 
+    fs = 12
     # various defaults - ones the user doesn't change in this quick Look code
     delTmax = 70
     polyV = 4 # polynomial order for the direct signal
@@ -132,6 +138,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     pltname = 'temp.png' # default plot
     requireAmp = reqAmp[0]
     screenstats = True
+    FS = 12
 
 # to avoid having to do all the indenting over again
 # this allows snr file to live in main directory
@@ -187,7 +194,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
         for a in range(naz):
             if pltscreen:
                 plt.subplot(2,2,bz[a])
-                plt.title(titles[a])
+                plt.title(titles[a],fontsize=fs)
             az1 = azval[(a*2)] ; az2 = azval[(a*2 + 1)]
             # this means no satellite list was given, so get them all
             if satsel == None:
@@ -235,9 +242,11 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                 plt.grid()
                 amax = max(amax,  bbb) # do not know how to implement this ...
                 if (a == 3) or (a==1):
-                    plt.xlabel('reflector height (m)')
+                    plt.xlabel('reflector height (m)',fontsize=FS)
                 if (a == 1) or (a==0):
-                    plt.ylabel('volts/volts')
+                    plt.ylabel('volts/volts',fontsize=FS)
+                plt.xticks(fontsize=FS)
+                plt.yticks(fontsize=FS)
 
         rhout.close()
         #print('preliminary reflector height results are stored in a file called logs/rh.txt')
@@ -245,9 +254,9 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
 
 
         if pltscreen:
-            plt.suptitle(tt, fontsize=12)
+            plt.suptitle(tt, fontsize=FS)
             # sure - throw in another plot
-            goodbad(quicklog,station,minH,maxH,PkNoise,reqAmp,f)
+            goodbad(quicklog,station,year,doy,minH,maxH,PkNoise,reqAmp,f)
             plt.show()
           
     else: 
@@ -259,7 +268,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     # 21mar26 added a key
     return data,datakey
 
-def goodbad(fname,station,h1,h2,PkNoise,reqAmp,freq):
+def goodbad(fname,station,year,doy,h1,h2,PkNoise,reqAmp,freq):
     """
     simple visualizer of "good" and "bad" azimuths
     input is a filename, the station name, and the min and max RH
@@ -282,12 +291,16 @@ def goodbad(fname,station,h1,h2,PkNoise,reqAmp,freq):
     plt.subplot(3,1,1)
     plt.plot(a[ij,0], a[ij,1], 'o',color='blue',label='good')
     plt.plot(a[ik,0], a[ik,1], 'o',color='gray', label='bad')
-    plt.title('quickLook Retrieval Metrics: ' + station + ' ' + g.ftitle(freq))
+    ydoy = ' ' + str(year) + '/' + str(doy) + ' '
+    plt.title('quickLook Retrieval Metrics: ' + station + ydoy + g.ftitle(freq),fontsize=fs)
     plt.legend(loc="upper right")
-    plt.ylabel('Reflector Height (m)')
+    plt.ylabel('Refl. Ht. (m)',fontsize=fs)
     plt.grid()
     plt.xlim((0, 360))
     plt.ylim((h1, h2))
+    plt.xticks(fontsize=fs)
+    plt.yticks(fontsize=fs)
+
     ax = plt.gca()
     ax.axes.xaxis.set_ticklabels([])
 
@@ -297,9 +310,11 @@ def goodbad(fname,station,h1,h2,PkNoise,reqAmp,freq):
     plt.plot(a[ij,0], a[ij,4], 'o',color='blue')
     plt.plot(a[ik,0], a[ik,4], 'o',color='gray')
     plt.legend(loc="upper right")
-    plt.ylabel('peak2noise')
+    plt.ylabel('peak2noise',fontsize=fs)
     plt.grid()
     plt.xlim((0, 360))
+    plt.xticks(fontsize=fs)
+    plt.yticks(fontsize=fs)
     ax = plt.gca()
     ax.axes.xaxis.set_ticklabels([])
 
@@ -308,9 +323,11 @@ def goodbad(fname,station,h1,h2,PkNoise,reqAmp,freq):
     plt.plot(a[ij,0], a[ij,3], 'o',color='blue')
     plt.plot(a[ik,0], a[ik,3], 'o',color='gray') 
     plt.legend(loc="upper right")
-    plt.ylabel('Spectral Peak Amplitude')
-    plt.xlabel('Azimuth (degrees)')
+    plt.ylabel('Spectral Peak Ampl.',fontsize=fs)
+    plt.xlabel('Azimuth (degrees)',fontsize=fs)
     plt.grid()
+    plt.xticks(fontsize=fs)
+    plt.yticks(fontsize=fs)
     plt.xlim((0, 360))
 
 # old code
