@@ -8,23 +8,33 @@ import os
 from scipy.interpolate import interp1d
 import subprocess
 import sys
+import time
 
+# progress bar for RINEX translation/orbits
+from progress.bar import Bar
 
+# my gps libraries
 import gnssrefl.gps as g
 import gnssrefl.rinpy as rinpy
 
+# fortran codes for translating RINEX
+import gnssrefl.gpssnr as gpssnr
+import gnssrefl.gnsssnr as gnsssnr 
+
+
 class constants:
     omegaEarth = 7.2921151467E-5 #      %rad/sec
     mu = 3.986005e14 # Earth GM value
     c= 299792458 # m/sec
  
+#
 #
 def quickname(station,year,cyy, cdoy, csnr):
     xdir  = os.environ['REFL_CODE'] + '/'
     fname =  xdir + str(year) + '/snr/' + station + '/' + station + cdoy + '0.' + cyy + '.snr' + csnr
     return fname
 
-def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,archive,fortran,nol,overwrite):
+def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,archive,fortran,nol,overwrite,translator,srate):
     """
     runs the rinex 2 snr conversion
     inputs:
@@ -39,6 +49,11 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     fortran = boolean, whether you use fortran rinex translators
     nol = boolean for nolook, if set to True, then it will assume RINEX files are in local directory
     overwrite = boolean, make a new SNR file even if one already exists
+
+    2021feb11, kristine Larson
+    translator = fortran, python, or hybrid
+    srate - integer sample rate, for RINEX 3 only.
+    2021mar20 check for illegal day of years ....
     """
 
     NS = len(station)
@@ -58,6 +73,7 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
 # loop thru years and days 
     for year in year_list:
         ann = g.make_nav_dirs(year)
+        dec31 = g.dec31(year)
         for doy in doy_list:
             csnr = str(isnr)
             cdoy = '{:03d}'.format(doy) ; cyy = '{:02d}'.format(year-2000)
@@ -66,15 +82,20 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
             #print(fname)
             snre = g.snr_exist(station,year,doy,csnr)
             if snre:
-                print('SNR file already exists', fname)
+                print('SNR file exists', fname)
                 if overwrite:
                     #print('you requested it be overwritten, so removing file')
                     subprocess.call(['rm', fname])
                     snre = False
-            if (not snre):
+            illegal_day = False
+            if (doy > dec31):
+                illegal_day = True
+                #print('illegal day',illegal_day, doy, dec31)
+            # combining these so i don't have to indent everything
+            if (not illegal_day) and (not snre):
                 r = station + cdoy + '0.' + cyy + 'o'
                 rgz = station + cdoy + '0.' + cyy + 'o.gz'
-                #print(station, year, doy, ': will try to find RINEX /make SNR ')
+                print('Will seek RINEX file ', station, ' year:', year, ' doy:', doy, ' translate with ', translator)
                 if nol:
                     # this assumes RINEX file is in local directory
                     if version == 2:
@@ -82,12 +103,14 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                             #print('RINEX 2 file exists locally')
                             if not os.path.exists(r):
                                 subprocess.call(['gunzip', rgz])
-                            conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran) 
+                            conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
                         else:
                             print('You Chose the No Look Option, but did not provide the needed RINEX file.')
                     if version == 3:
-                        r3 = station9ch + '_R_' + str(year) + cdoy + '0000_01D_30S_MO.rnx'
-                        r3gz = station9ch + '_R_' + str(year) + cdoy + '0000_01D_30S_MO.rnx.gz'
+##                        print(' 2021feb22 using sample rate explicitly')
+                        # this is going to fail when srate < 10
+                        r3 = station9ch + '_R_' + str(year) + cdoy + '0000_01D_' + str(srate) + 'S_MO.rnx'
+                        r3gz = station9ch + '_R_' + str(year) + cdoy + '0000_01D_' + str(srate) + 'S_MO.rnx.gz'
                         r2 = station + cdoy + '0.' + cyy + 'o'
                         if os.path.exists(r3gz):
                             subprocess.call(['gunzip', r3gz])
@@ -96,7 +119,7 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                             fexists = g.new_rinex3_rinex2(r3,r2)
                             if fexists:
                                 #print('Rinex 3 to 2 conversion worked, now convert to snr format')
-                                conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran) 
+                                conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
                             else:
                                 print('Something about the RINEX 3-2 conversion did not work')
                         else:
@@ -105,25 +128,31 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                 else:
                     #print('will look for the RINEX file both locally and externally')
                     if version == 3:
-                        #print('rinex 3 search with orbtype ', orbtype)
-                        srate = 30 # rate supported by CDDIS 
-                        rinex2exists, rinex3name = g.cddis_rinex3(station9ch, year, doy,srate,orbtype)
-                        if not rinex2exists:
-                        # try again - unavco has 15 sec I believe
+                        #  try unavco
+                        if (archive == 'all') or (archive == 'unavco'):
                             srate = 15
                             rinex2exists, rinex3name = g.unavco_rinex3(station9ch, year, doy,srate,orbtype)
+
+                        # try cddis
+                        if not os.path.exists(r):
+                            if (archive == 'all') or (archive == 'cddis'):
+                                srate = 30
+                                rinex2exists, rinex3name = g.cddis_rinex3(station9ch, year, doy,srate,orbtype)
+
+                        # remove rinex 3 file
                         subprocess.call(['rm', '-f', rinex3name]) # remove rinex3 file
+
                         if rinex2exists:
-                            conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran) 
+                            conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
                         else:
                             print('RINEX file does not exist for ', year, doy)
                     else:
                         # this is rinex version 2
-                        conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran) 
+                        conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
 
-    print('And I guess my work is done now!')
+    #print('And I guess my work is done now!')
 
-def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,fortran):
+def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,fortran,translator):
     """
     inputs: year and day of year (integers) and station name
     option is for the snr creation ??? integer or character?
@@ -148,10 +177,6 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
     log.write("Receiver rate: {0:5s} \n".format(receiverrate))
     log.write("Decimation rate: {0:3.0f} \n".format(dec_rate))
     log.write("Archive: {0:10s} \n".format(archive))
-    if fortran:
-        log.write("Use Fortran: {0:4s} \n".format('True'))
-    else:
-        log.write("Use Fortran: {0:5s} \n".format('False'))
     log.write("Orbits : {0:10s} \n".format(orbtype))
     exedir = os.environ['EXE']
     snrname_full, snrname_compressed, snre = g.define_and_xz_snr(station,year,doy,option)
@@ -170,54 +195,75 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
             rinexfile,rinexfiled = g.rinex_name(station, year, month, day)
             # This goes to find the rinex file. I am changing it to allow 
             # an archive preference 
-             
             g.go_get_rinex_flex(station,year,month,day,receiverrate,archive)
-# define booleans
+#           define booleans for various files
             oexist = os.path.isfile(orbdir + '/' + f) == True
             rexist = os.path.isfile(rinexfile) == True
             exc = exedir + '/teqc' 
             texist = os.path.isfile(exc) == True
-            if rexist:
-                if texist and fortran:
-                    # only do this for the older version
-                    #print('teqc executable exists, will use to eliminate unnecessary observables')
-                    #foutname = 'tmp.' + rinexfile
-                    #fout = open(foutname,'w')
-                    #subprocess.call([exc, '-O.obs','S1+S2+S5+S6+S7+S8', '-n_GLONASS', '27', rinexfile],stdout=fout)
-                    #fout.close()
-                    log.write('This option deprecated - no longer use teqc for reducing observables \n')
-                # store it in the original rinex filename
-                    #subprocess.call(['rm','-f',rinexfile])
-                    #subprocess.call(['mv','-f',foutname, rinexfile])
-                # decimate this new rinex file
-                    if (rexist and dec_rate > 0): 
-                        log.write("Decimating using teqc:  {0:3.0f}  seconds \n".format(dec_rate))
-                        log.write('Unfortunately teqc removes Beidou data. Eventually I will remove this. \n')
-                        rinexout = rinexfile + '.tmp'; cdec = str(dec_rate)
-                        fout = open(rinexout,'w')
-                        subprocess.call([exc, '-O.dec', cdec, rinexfile],stdout=fout)
-                        fout.close() # needed?
-                        status = subprocess.call(['mv','-f', rinexout, rinexfile])
-            # orbits and rinexfile exist
-            if (oexist and rexist):
+            if rexist: 
+                # decimate using teqc 
+                if (texist) and (fortran) and (dec_rate > 0): 
+                    log.write("Decimating using teqc:  {0:3.0f}  seconds \n".format(dec_rate))
+                    log.write('Unfortunately teqc removes Beidou data. Eventually I will remove this. \n')
+                    rinexout = rinexfile + '.tmp'; cdec = str(dec_rate)
+                    fout = open(rinexout,'w')
+                    subprocess.call([exc, '-O.dec', cdec, rinexfile],stdout=fout)
+                    fout.close() # needed?
+                    status = subprocess.call(['mv','-f', rinexout, rinexfile])
+            # if orbits and rinexfile exist
+            if (oexist) and (rexist):
                 snrname = g.snr_name(station, year,month,day,option)
                 orbfile = orbdir + '/' + f
-                if fortran:
-                    try:
-                        #subprocess.call([snrexe, rinexfile, snrname, orbfile, str(option)])
-                        log.write('Using fortran for translation  - separate log is used for stdout \n')
-                        flogname = 'logs/' + station + '_fortran.txt'
-                        flog = open(flogname, 'w+')
-                        a=subprocess.run([snrexe, rinexfile, snrname, orbfile, str(option)],capture_output=True,text=True)
-                        ddd = a.stdout; flog.write(ddd); flog.close()
-                        status = subprocess.call(['rm','-f', rinexfile ])
-                        status = subprocess.call(['xz', orbfile])
-                    except:
-                        log.write('Problem with making SNR file, check log {0:50s} \n'.format(flogname))
+                #print('translator',translator)
+                if translator == 'hybrid':
+                    g.make_snrdir(year,station) # make sure output directory exists
+                    in1 = g.binary(rinexfile)
+                    in2 = g.binary(snrname) # this file is made locally and moved later
+                    in3 = g.binary(orbfile)
+                    if (len(snrname) > 132) or (len(orbfile) > 132):
+                        print('The orbit or SNR file name is too long.')
+                        print('Make your environment variable names shorter.')
+                        return
+                    in4 = g.binary(str(option))
+                    if (dec_rate > 0):
+                        decr = str(dec_rate)
+                    else:
+                        decr = '0'
+                    in5 = g.binary(decr) # decimation can be used in hybrid option
+                    message = 'None '
+                    errorlog = 'logs/' + station + '_hybrid_error.txt'
+                    in6 = g.binary(errorlog)
+                    log.write('SNR file {0:50s} \n will use hybrid of python and fortran to make \n'.format( snrname))
+                    # these are calls to the fortran codes that have been ported to be called from python
+                    if (orbtype  == 'gps') or (orbtype == 'nav'):
+                        gpssnr.foo(in1,in2,in3,in4,in5,in6)
+                    else:
+                        gnsssnr.foo(in1,in2,in3,in4,in5,in6)
                 else:
-                    log.write('SNR file {0:50s} \n will not use fortran to make \n'.format( snrname))
-                    log.write('Decimating will be done here instead of using teqc \n')
-                    rnx2snr(rinexfile, orbfile,snrname,option,year,month,day,dec_rate,log)
+                    if (translator == 'fortran'):
+                        t1=time.time()
+                        try:
+                            #subprocess.call([snrexe, rinexfile, snrname, orbfile, str(option)])
+                            log.write('Using standalone fortran for translation  - separate log is used for stdout \n')
+                            flogname = 'logs/' + station + '_fortran.txt'
+                            flog = open(flogname, 'w+')
+                            a=subprocess.run([snrexe, rinexfile, snrname, orbfile, str(option)],capture_output=True,text=True)
+                            ddd = a.stdout; flog.write(ddd); flog.close()
+                            status = subprocess.call(['rm','-f', rinexfile ])
+                            status = subprocess.call(['xz', orbfile])
+                        except:
+                            log.write('Problem with making SNR file, check fortran specific log {0:50s} \n'.format(flogname))
+                        t2=time.time()
+#                        print(' Exec time:', '{0:4.2f}'.format(t2-t1) )
+# this is for people that want to use slow python code
+                    else:
+                        log.write('SNR file {0:50s} \n will use python to make \n'.format( snrname))
+                        log.write('Decimating will be done here instead of using teqc \n')
+                        t1=time.time()
+                        rnx2snr(rinexfile, orbfile,snrname,option,year,month,day,dec_rate,log)
+                        t2=time.time()
+#                        print(' Exec time:', '{0:4.2f}'.format(t2-t1) )
 
                 # remove the rinex file
                 subprocess.call(['rm', '-f',rinexfile])
@@ -231,11 +277,15 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
                     else:
                         log.write('A SNR file was created: {0:50s}  \n'.format(snrname_full))
                         print('\n')
-                        print('A SNR file was created:', snrname_full)
+                        print('SUCCESS: SNR file was created:', snrname_full)
                         g.store_snrfile(snrname,year,station) 
+                else:
+                    print('No SNR file was created - check logs section for additional information')
             else:
                 print('Either the RINEX file or orbit file does not exist, so there is nothing to convert')
                 log.write('Either the RINEX file or orbit file does not exist, so there is nothing to convert \n')
+        else:
+            print('The orbit file you requested does not exist.')
 
     # close the log file
     log.close()
@@ -364,7 +414,8 @@ def rnx2snr(obsfile, navfile,snrfile,snroption,year,month,day,dec_rate,log):
         navorbits(navfile,obstimes,obsdata,obslist,prntoidx,gpssatlist,snrfile,s1exist,s2exist,s5exist,up,East,North,emin,emax,recv,dec_rate,log)
     else:
         log.write('Read the sp3 file \n'); sp3 = g.read_sp3file(navfile)
-        test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day,emin,emax,snrfile,up,East,North,recv,dec_rate,log)
+        testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day,emin,emax,snrfile,up,East,North,recv,dec_rate,log)
+        #test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day,emin,emax,snrfile,up,East,North,recv,dec_rate,log)
 
     #print('Closing python RINEX conversion log file:',logname)
     #log.close()
@@ -393,28 +444,30 @@ def navorbits(navfile,obstimes,observationdata,obslist,prntoidx,gpssatlist,snrfi
         log.write('Number of epochs in the RINEX file {0:6.0f} \n '.format( K))
         log.write('Decimation rate {0:3.0f} \n'.format(dec_rate))
 
-        for i in range(0,K):
-            if np.remainder(i,1000) == 0:
-                log.write('Epoch {0:6.0f} \n'.format( i))
+        with Bar('Processing RINEX', max=K,fill='@',suffix='%(percent)d%%') as bar:
+            for i in range(0,K):
+                bar.next()
+                if np.remainder(i,200) == 0:
+                    log.write('Epoch {0:6.0f} \n'.format( i))
             # sod is seconds of the day
-            sod = 3600*a[i].hour + 60*a[i].minute + a[i].second
-            if dec_rate > 0:
-                rem = sod % dec_rate
-            else:
-                rem = 0
-            if (rem == 0):
-                gweek, gpss = g.kgpsweek(a[i].year, a[i].month, a[i].day, a[i].hour, a[i].minute, a[i].second)
-                for sat in gpssatlist:
-                    s1,s2,s5 = readSNRval(s1exist,s2exist,s5exist,observationdata,prntoidx,sat,i)
-                    if (s1 > 0):
-                        closest = g.myfindephem(gweek, gpss, ephemdata, sat)
-                        if len(closest) > 0:
-                            satv = satorb_prop(gweek, gpss, sat, recv, closest)
-                            r=np.subtract(satv,recv) # satellite minus receiver vector
-                            eleA = g.elev_angle(up, r)*180/np.pi
-                            azimA = g.azimuth_angle(r, East, North)
-                            if (eleA >= emin) and (eleA <= emax):
-                                fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} \n".format(sat,eleA, azimA, sod,0, 0, s1,s2, s5))
+                sod = 3600*a[i].hour + 60*a[i].minute + a[i].second
+                if dec_rate > 0:
+                    rem = sod % dec_rate
+                else:
+                    rem = 0
+                if (rem == 0):
+                    gweek, gpss = g.kgpsweek(a[i].year, a[i].month, a[i].day, a[i].hour, a[i].minute, a[i].second)
+                    for sat in gpssatlist:
+                        s1,s2,s5 = readSNRval(s1exist,s2exist,s5exist,observationdata,prntoidx,sat,i)
+                        if (s1 > 0):
+                            closest = g.myfindephem(gweek, gpss, ephemdata, sat)
+                            if len(closest) > 0:
+                                satv = satorb_prop(gweek, gpss, sat, recv, closest)
+                                r=np.subtract(satv,recv) # satellite minus receiver vector
+                                eleA = g.elev_angle(up, r)*180/np.pi
+                                azimA = g.azimuth_angle(r, East, North)
+                                if (eleA >= emin) and (eleA <= emax):
+                                    fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} \n".format(sat,eleA, azimA, sod,0, 0, s1,s2, s5))
         fout.close()
     else:
         log.write('There was some kind of problem with your file, exiting ...\n')
@@ -646,3 +699,95 @@ def testit(input):
     """
     print(input)
     return True
+
+
+def testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day, emin,emax,outputfile,up,East,North,recv,dec_rate,log):
+    """
+    inputs are gpstime( numpy array with week and sow)
+    sp3 is what has been read from the sp3 file
+    columsn are satNu, week, sow, x, y, z (in meters)
+    log is for comments
+    """
+    checkD = False
+    if dec_rate > 0:
+        checkD = True
+        log.write('You are decimating \n')
+    # epoch at the beginning of the day of your RINEX file
+    gweek0, gpssec0 = g.kgpsweek(year, month,day,0,0,0 )
+
+    ll = 'quadratic'
+#   will store in this variable, then sort it before writing out to a file
+    saveit = np.empty(shape=[0,11] )
+    fout = open(outputfile, 'w+')
+    NsatT = 0
+    # make a dictionary for constellation name
+    sname ={}; sname['G']='GPS' ; sname['R'] = 'GLONASS'; sname['E'] = 'GALILEO'; sname['C']='BEIDOU'
+    for con in ['G','E','R','C']:
+        if con in obstypes:
+            satL = len(systemsatlists[con][:])
+            satS = 'Processing ' + sname[con]
+            with Bar(satS, max=satL,fill='@',suffix='%(percent)d%%') as bar:
+                log.write('Good news - found data for constellation {0:s} \n'.format( con))
+                obslist = obstypes[con][:]
+                satlist = systemsatlists[con][:]
+                for prn in satlist:
+                    bar.next()
+                    addon = g.findConstell(con) # 100,200,or 300 for R,E, and C 
+                    log.write('Constellation {0:1s} Satellite {1:2.0f}  Addon {2:3.0f} \n'.format( con, prn, addon))
+                # window out the data for this satellite
+                    m = sp3[:,0] == prn + addon
+                    x = sp3[m,3]
+                    if len(x) > 0:
+                        sp3_week = sp3[m,1] ; sp3_sec = sp3[m,2]
+                        x = sp3[m,3] ; y = sp3[m,4] ; z = sp3[m,5]
+                # fit the orbits for this satellite
+                        t=sp3_sec
+                        iX= interp1d(t, x, ll,bounds_error=False,fill_value='extrapolate')
+                        iY= interp1d(t, y, ll,bounds_error=False,fill_value='extrapolate')
+                        iZ= interp1d(t, z, ll,bounds_error=False,fill_value='extrapolate')
+        # get the S1 data for this satellite
+                        if 'S1' in obslist:
+                            s1 = obsdata[con]['S1'][:, prntoidx[con][prn]]
+
+        # indices when there are no data for this satellite
+                        ij = np.isnan(s1)
+        # indices when there are data in the RINEX file - this way you do not compute 
+        # orbits unless there are data.
+                        not_ij = np.logical_not(ij)
+                        Tp = gpstime[not_ij,1] # only use the seconds of the week for now
+                        s1 = s1[not_ij]; 
+                    #print(s1.shape)
+                        emp = np.zeros(shape=[len(s1),1],dtype=float)
+        # get the rest of the SNR data in a function
+                        s2,s5,s6,s7,s8 = extract_snr(prn, con, obslist,obsdata,prntoidx,not_ij,emp)
+        # make sure there are no nan values in s2 or s5
+
+                        nepochs = len(Tp)
+                        for ij in range(0,nepochs):
+                            TT = 0 # default value
+                            if checkD:
+                                TT = Tp[ij]  % dec_rate # get the modulus
+                            if TT == 0:
+                                SatOrb = satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij) 
+                                r=np.subtract(SatOrb,recv)
+                                azimA = g.azimuth_angle(r, East, North)
+                                eleA = g.elev_angle(up, r)*180/np.pi
+                                if (eleA >= emin) and (eleA <= emax):
+                                    fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} {9:7.2f} {10:7.2f} \n".format( 
+                                        prn+addon,eleA,azimA,Tp[ij]-gpssec0, 0,float(s6[ij]),s1[ij],float(s2[ij]),float(s5[ij]),float(s6[ij]),float(s7[ij]) ))
+                    else:
+                        log.write('This satellite is not in the orbit file. {0:3.0f} \n'.format(prn))
+        else:
+            log.write('No data for constellation {0:1s} \n'.format(con))
+    log.write('write SNR data to file \n')
+    fout.close()
+
+                    # only do this for the older version
+                    #print('teqc executable exists, will use to eliminate unnecessary observables')
+                    #foutname = 'tmp.' + rinexfile
+                    #fout = open(foutname,'w')
+                    #subprocess.call([exc, '-O.obs','S1+S2+S5+S6+S7+S8', '-n_GLONASS', '27', rinexfile],stdout=fout)
+                    #fout.close()
+                # store it in the original rinex filename
+                    #subprocess.call(['rm','-f',rinexfile])
+                    #subprocess.call(['mv','-f',foutname, rinexfile])
