@@ -30,7 +30,7 @@ def main():
 # optional arguments
     parser.add_argument("-snr", default=66, help="snr file ending", type=str)
     parser.add_argument("-orb", default='nav', type=str, help="orbit type, gps, gps+glo, gnss or you can specify nav,igs,igr,jax,gbm,grg,wum")
-    parser.add_argument("-rate", default='low', metavar='low',type=str, help="sample rate: low or high, only unavco")
+    parser.add_argument("-rate", default='low', metavar='low',type=str, help="sample rate: low or high")
     parser.add_argument("-dec", default=0, type=int, help="decimate (seconds)")
     parser.add_argument("-nolook", default='False', metavar='False', type=str, help="True means only use RINEX files on local machine")
     parser.add_argument("-fortran", default='True', metavar='True',type=str, help="True means use Fortran RINEX translators ")
@@ -68,7 +68,8 @@ def main():
     #isnr = int(snrt)
     orb = args.orb
 # currently allowed orbit types - shanghai removed 2020sep08
-    orbit_list = ['gps','gps+glo','gnss','nav', 'igs','igr','jax','gbm','grg','wum']
+# added GFZ rapid, aka gfr 2021May19
+    orbit_list = ['gps','gps+glo','gnss','nav', 'igs','igr','jax','gbm','grg','wum','gfr']
     if orb not in orbit_list:
         print('You picked an orbit type I do not recognize. Here are the ones I allow')
         print(orbit_list)
@@ -86,8 +87,6 @@ def main():
     if orb == 'gps+glo':
         orb = 'jax'
 
-
-
     if args.fortran == 'True':
         fortran = True
     else:
@@ -120,7 +119,7 @@ def main():
     else:
         nol = False
 
-    # default is set to low.  pick high for 1sec files from unavco
+    # default is set to low.  pick high for 1sec files 
     rate = args.rate
 
     if args.doy_end == None:
@@ -130,7 +129,7 @@ def main():
 
 
 # currently allowed archives 
-    archive_list = ['sopac', 'unavco','sonel','cddis','nz','ga','bkg','jeff','ngs','nrcan','special']
+    archive_list = ['sopac', 'unavco','sonel','cddis','nz','ga','bkg','jeff','ngs','nrcan','special','bev']
     if args.archive == None:
         archive = 'all'
     else:
